@@ -55,7 +55,7 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
             right,
             op: op @ op!("&&"),
             ..
-        }) if is_ok_to_negate_rhs(&right) => {
+        }) if is_ok_to_negate_rhs(right) => {
             tracing::debug!("negate: a && b => !a || !b");
 
             let a = negate(&mut **left, in_bool_ctx, false);
@@ -69,7 +69,7 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
             right,
             op: op @ op!("||"),
             ..
-        }) if is_ok_to_negate_rhs(&right) => {
+        }) if is_ok_to_negate_rhs(right) => {
             tracing::debug!("negate: a || b => !a && !b");
 
             let a = negate(&mut **left, in_bool_ctx, false);
@@ -79,7 +79,7 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
         }
 
         Expr::Cond(CondExpr { cons, alt, .. })
-            if is_ok_to_negate_for_cond(&cons) && is_ok_to_negate_for_cond(&alt) =>
+            if is_ok_to_negate_for_cond(cons) && is_ok_to_negate_for_cond(alt) =>
         {
             tracing::debug!("negate: cond");
 
@@ -101,10 +101,11 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
 
     let mut arg = Box::new(e.take());
 
-    match &mut *arg {
-        Expr::Unary(UnaryExpr {
-            op: op!("!"), arg, ..
-        }) => match &mut **arg {
+    if let Expr::Unary(UnaryExpr {
+        op: op!("!"), arg, ..
+    }) = &mut *arg
+    {
+        match &mut **arg {
             Expr::Unary(UnaryExpr { op: op!("!"), .. }) => {
                 tracing::debug!("negate: !!bool => !bool");
                 *e = *arg.take();
@@ -126,9 +127,7 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
                     return true;
                 }
             }
-        },
-
-        _ => {}
+        }
     }
 
     if is_ret_val_ignored {
@@ -154,10 +153,7 @@ pub(super) fn negate(e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
 }
 
 pub(crate) fn is_ok_to_negate_for_cond(e: &Expr) -> bool {
-    match e {
-        Expr::Update(..) => false,
-        _ => true,
-    }
+    !matches!(e, Expr::Update(..))
 }
 
 pub(crate) fn is_ok_to_negate_rhs(rhs: &Expr) -> bool {
@@ -177,10 +173,10 @@ pub(crate) fn is_ok_to_negate_rhs(rhs: &Expr) -> bool {
             left,
             right,
             ..
-        }) => is_ok_to_negate_rhs(&left) && is_ok_to_negate_rhs(&right),
+        }) => is_ok_to_negate_rhs(left) && is_ok_to_negate_rhs(right),
 
         Expr::Bin(BinExpr { left, right, .. }) => {
-            is_ok_to_negate_rhs(&left) && is_ok_to_negate_rhs(&right)
+            is_ok_to_negate_rhs(left) && is_ok_to_negate_rhs(right)
         }
 
         Expr::Assign(e) => is_ok_to_negate_rhs(&e.right),
@@ -192,7 +188,7 @@ pub(crate) fn is_ok_to_negate_rhs(rhs: &Expr) -> bool {
 
         Expr::Seq(e) => {
             if let Some(last) = e.exprs.last() {
-                is_ok_to_negate_rhs(&last)
+                is_ok_to_negate_rhs(last)
             } else {
                 true
             }
@@ -233,15 +229,14 @@ pub(crate) fn negate_cost(e: &Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
                     op: op!("!"), arg, ..
                 }) => {
                     // TODO: Check if this argument is actually start of line.
-                    match &**arg {
-                        Expr::Call(CallExpr {
-                            callee: Callee::Expr(callee),
-                            ..
-                        }) => match &**callee {
-                            Expr::Fn(..) => return 0,
-                            _ => {}
-                        },
-                        _ => {}
+                    if let Expr::Call(CallExpr {
+                        callee: Callee::Expr(callee),
+                        ..
+                    }) = &**arg
+                    {
+                        if let Expr::Fn(..) = &**callee {
+                            return 0;
+                        }
                     }
 
                     match &**arg {
@@ -280,19 +275,19 @@ pub(crate) fn negate_cost(e: &Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
                     right,
                     ..
                 }) => {
-                    let l_cost = cost(&left, in_bool_ctx, Some(*op), false);
+                    let l_cost = cost(left, in_bool_ctx, Some(*op), false);
 
-                    if !is_ret_val_ignored && !is_ok_to_negate_rhs(&right) {
+                    if !is_ret_val_ignored && !is_ok_to_negate_rhs(right) {
                         return l_cost + 3;
                     }
-                    l_cost + cost(&right, in_bool_ctx, Some(*op), is_ret_val_ignored)
+                    l_cost + cost(right, in_bool_ctx, Some(*op), is_ret_val_ignored)
                 }
 
                 Expr::Cond(CondExpr { cons, alt, .. })
-                    if is_ok_to_negate_for_cond(&cons) && is_ok_to_negate_for_cond(&alt) =>
+                    if is_ok_to_negate_for_cond(cons) && is_ok_to_negate_for_cond(alt) =>
                 {
-                    cost(&cons, in_bool_ctx, bin_op, is_ret_val_ignored)
-                        + cost(&alt, in_bool_ctx, bin_op, is_ret_val_ignored)
+                    cost(cons, in_bool_ctx, bin_op, is_ret_val_ignored)
+                        + cost(alt, in_bool_ctx, bin_op, is_ret_val_ignored)
                 }
 
                 Expr::Cond(..)
@@ -312,7 +307,7 @@ pub(crate) fn negate_cost(e: &Expr, in_bool_ctx: bool, is_ret_val_ignored: bool)
 
                 Expr::Seq(e) => {
                     if let Some(last) = e.exprs.last() {
-                        return cost(&last, in_bool_ctx, bin_op, is_ret_val_ignored);
+                        return cost(last, in_bool_ctx, bin_op, is_ret_val_ignored);
                     }
 
                     if is_ret_val_ignored {
@@ -385,7 +380,7 @@ pub(crate) fn is_valid_identifier(s: &str, ascii_only: bool) -> bool {
 
     s.starts_with(|c: char| c.is_xid_start())
         && s.chars().all(|c: char| c.is_xid_continue())
-        && !s.contains("𝒶")
+        && !s.contains('𝒶')
         && !s.is_reserved()
 }
 
@@ -400,11 +395,7 @@ pub(crate) fn is_directive(e: &Stmt) -> bool {
 }
 
 pub(crate) fn is_pure_undefined_or_null(e: &Expr) -> bool {
-    is_pure_undefined(e)
-        || match e {
-            Expr::Lit(Lit::Null(..)) => true,
-            _ => false,
-        }
+    is_pure_undefined(e) || matches!(e, Expr::Lit(Lit::Null(..)))
 }
 
 /// This method does **not** modifies `e`.
@@ -419,8 +410,8 @@ pub(crate) fn eval_as_number(e: &Expr) -> Option<f64> {
             right,
             ..
         }) => {
-            let l = eval_as_number(&left)?;
-            let r = eval_as_number(&right)?;
+            let l = eval_as_number(left)?;
+            let r = eval_as_number(right)?;
 
             return Some(l - r);
         }
@@ -436,12 +427,13 @@ pub(crate) fn eval_as_number(e: &Expr) -> Option<f64> {
                 }
             }
 
-            match &**callee {
-                Expr::Member(MemberExpr {
-                    obj,
-                    prop: MemberProp::Ident(prop),
-                    ..
-                }) => match &**obj {
+            if let Expr::Member(MemberExpr {
+                obj,
+                prop: MemberProp::Ident(prop),
+                ..
+            }) = &**callee
+            {
+                match &**obj {
                     Expr::Ident(obj) if &*obj.sym == "Math" => match &*prop.sym {
                         "cos" => {
                             let v = eval_as_number(&args.first()?.expr)?;
@@ -503,8 +495,7 @@ pub(crate) fn eval_as_number(e: &Expr) -> Option<f64> {
                         _ => {}
                     },
                     _ => {}
-                },
-                _ => {}
+                }
             }
         }
 
@@ -536,7 +527,7 @@ pub(crate) fn always_terminates(s: &Stmt) -> bool {
     match s {
         Stmt::Return(..) | Stmt::Throw(..) | Stmt::Break(..) | Stmt::Continue(..) => true,
         Stmt::If(IfStmt { cons, alt, .. }) => {
-            always_terminates(&cons) && alt.as_deref().map(always_terminates).unwrap_or(false)
+            always_terminates(cons) && alt.as_deref().map(always_terminates).unwrap_or(false)
         }
         Stmt::Block(s) => s.stmts.iter().any(always_terminates),
 
